"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hasString = exports.bytesToString = exports.isEmptyString = exports.endsWithCRLF = exports.isLF = void 0;
const LF = 0x0A;
const CR = 0x0D;

const isLF = byte => byte === LF;

exports.isLF = isLF;

const endsWithCRLF = bytes => {
  const {
    length
  } = bytes;
  return bytes[length - 2] === CR && bytes[length - 1] === LF;
};

exports.endsWithCRLF = endsWithCRLF;

const isEmptyString = bytes => {
  const {
    length
  } = bytes;
  return length === 2 && endsWithCRLF(bytes) || length === 1 && bytes[0] === LF;
};

exports.isEmptyString = isEmptyString;

const bytesToString = (bytes, encoding) => Buffer.from(bytes).toString(encoding);

exports.bytesToString = bytesToString;

const stringToBytes = (string, encoding) => Array.from(Buffer.from(string, encoding));

const hasString = (bytes, str) => {
  const strLength = stringToBytes(str).length;

  if (bytes.length > strLength + 2) {
    return false;
  }

  return bytesToString(bytes).trim() === str;
};

exports.hasString = hasString;